@@ -38,31 +38,48 @@ class SubmissionSubmitStep4Form extends PKPSubmissionSubmitStep4Form {
 		$submission = $this->submission;
 		// Send author notification email
 		import('classes.mail.ArticleMailTemplate');
-		$mail = new ArticleMailTemplate($submission, 'SUBMISSION_ACK', null, null, false);
-		$authorMail = new ArticleMailTemplate($submission, 'SUBMISSION_ACK_NOT_USER', null, null, false);
-
 		$request = Application::get()->getRequest();
 		$context = $request->getContext();
 		$router = $request->getRouter();
+		$user = $request->getUser();
+
+		$mail = new ArticleMailTemplate($submission, 'SUBMISSION_ACK', null, null, false);
 		if ($mail->isEnabled()) {
 			// submission ack emails should be from the contact.
 			$mail->setFrom($this->context->getData('contactEmail'), $this->context->getData('contactName'));
+			$mail->addRecipient($user->getEmail(), $user->getFullName());
+
+			$mail->bccAssignedSubEditors($submission->getId(), WORKFLOW_STAGE_ID_SUBMISSION);
+
+			$mail->assignParams([
+				'authorName' => htmlspecialchars($user->getFullName()),
+				'authorUsername' => htmlspecialchars($user->getUsername()),
+				'editorialContactSignature' => htmlspecialchars($context->getData('contactName')),
+				'submissionUrl' => $router->url($request, null, 'authorDashboard', 'submission', $submission->getId()),
+			]);
+
+			if (!$mail->send($request)) {
+				import('classes.notification.NotificationManager');
+				$notificationMgr = new NotificationManager();
+				$notificationMgr->createTrivialNotification($request->getUser()->getId(), NOTIFICATION_TYPE_ERROR, array('contents' => __('email.compose.error')));
+			}
+		}
+
+		$authorMail = new ArticleMailTemplate($submission, 'SUBMISSION_ACK_NOT_USER', null, null, false);
+		if ($authorMail->isEnabled()) {
 			$authorMail->setFrom($this->context->getData('contactEmail'), $this->context->getData('contactName'));
 
-			$user = $request->getUser();
 			$primaryAuthor = $submission->getPrimaryAuthor();
 			if (!isset($primaryAuthor)) {
 				$authors = $submission->getAuthors();
 				$primaryAuthor = $authors[0];
 			}
-			$mail->addRecipient($user->getEmail(), $user->getFullName());
 
 			if ($user->getEmail() != $primaryAuthor->getEmail()) {
 				$authorMail->addRecipient($primaryAuthor->getEmail(), $primaryAuthor->getFullName());
 			}
 
 			$assignedAuthors = $submission->getAuthors();
-
 			foreach ($assignedAuthors as $author) {
 				$authorEmail = $author->getEmail();
 				// only add the author email if they have not already been added as the primary author
@@ -71,34 +88,17 @@ class SubmissionSubmitStep4Form extends PKPSubmissionSubmitStep4Form {
 					$authorMail->addRecipient($author->getEmail(), $author->getFullName());
 				}
 			}
-			$mail->bccAssignedSubEditors($submission->getId(), WORKFLOW_STAGE_ID_SUBMISSION);
 
-			$mail->assignParams(array(
-				'authorName' => $user->getFullName(),
-				'authorUsername' => $user->getUsername(),
-				'editorialContactSignature' => $context->getData('contactName'),
-				'submissionUrl' => $router->url($request, null, 'authorDashboard', 'submission', $submission->getId()),
-			));
+			$authorMail->assignParams([
+				'submitterName' => htmlspecialchars($user->getFullName()),
+				'editorialContactSignature' => htmlspecialchars($context->getData('contactName')),
+			]);
 
-			$authorMail->assignParams(array(
-				'submitterName' => $user->getFullName(),
-				'editorialContactSignature' => $context->getData('contactName'),
-			));
-
-			if (!$mail->send($request)) {
+			if (!empty($authorMail->getRecipients()) && !$authorMail->send($request)) {
 				import('classes.notification.NotificationManager');
 				$notificationMgr = new NotificationManager();
 				$notificationMgr->createTrivialNotification($request->getUser()->getId(), NOTIFICATION_TYPE_ERROR, array('contents' => __('email.compose.error')));
 			}
-
-			$recipients = $authorMail->getRecipients();
-			if (!empty($recipients)) {
-				if (!$authorMail->send($request)) {
-					import('classes.notification.NotificationManager');
-					$notificationMgr = new NotificationManager();
-					$notificationMgr->createTrivialNotification($request->getUser()->getId(), NOTIFICATION_TYPE_ERROR, array('contents' => __('email.compose.error')));
-				}
-			}
 		}
 
 		// Log submission.
