@@ -3,9 +3,9 @@
 /**
  * @file classes/cliTool/ScheduledTaskTool.inc.php
  *
- * Copyright (c) 2014-2019 Simon Fraser University
- * Copyright (c) 2000-2019 John Willinsky
- * Distributed under the GNU GPL v2. For full terms see the file docs/COPYING.
+ * Copyright (c) 2014-2021 Simon Fraser University
+ * Copyright (c) 2000-2021 John Willinsky
+ * Distributed under the GNU GPL v3. For full terms see the file docs/COPYING.
  *
  * @class ScheduledTaskTool
  * @ingroup tools
@@ -20,6 +20,7 @@ define('TASKS_REGISTRY_FILE', 'registry/scheduledTasks.xml');
 import('lib.pkp.classes.scheduledTask.ScheduledTask');
 import('lib.pkp.classes.scheduledTask.ScheduledTaskHelper');
 import('lib.pkp.classes.scheduledTask.ScheduledTaskDAO');
+import('lib.pkp.classes.xml.PKPXMLParser');
 
 class ScheduledTaskTool extends CommandLineTool {
 	/** @var string the XML file listing the tasks to be executed */
@@ -71,11 +72,10 @@ class ScheduledTaskTool extends CommandLineTool {
 	 * @param $file string
 	 */
 	function parseTasks($file) {
-		$xmlParser = new XMLParser();
+		$xmlParser = new PKPXMLParser();
 		$tree = $xmlParser->parse($file);
 
 		if (!$tree) {
-			$xmlParser->destroy();
 			printf("Unable to parse file \"%s\"!\n", $file);
 			exit(1);
 		}
@@ -95,8 +95,6 @@ class ScheduledTaskTool extends CommandLineTool {
 				$this->executeTask($className, ScheduledTaskHelper::getTaskArgs($task));
 			}
 		}
-
-		$xmlParser->destroy();
 	}
 
 	/**
