@@ -3,9 +3,9 @@
 /**
  * @file classes/plugins/PKPViewableFilePlugin.inc.php
  *
- * Copyright (c) 2014-2016 Simon Fraser University Library
- * Copyright (c) 2003-2016 John Willinsky
- * Distributed under the GNU GPL v2. For full terms see the file docs/COPYING.
+ * Copyright (c) 2014-2021 Simon Fraser University
+ * Copyright (c) 2003-2021 John Willinsky
+ * Distributed under the GNU GPL v3. For full terms see the file docs/COPYING.
  *
  * @class ViewableFilePlugin
  * @ingroup plugins
@@ -16,12 +16,6 @@
 import('lib.pkp.classes.plugins.GenericPlugin');
 
 abstract class PKPViewableFilePlugin extends GenericPlugin {
-	/**
-	 * Constructor
-	 */
-	function PKPViewableFilePlugin() {
-		parent::GenericPlugin();
-	}
 
 	/**
 	 * Get the filename of the template. (Default behavior may
@@ -36,4 +30,4 @@ abstract class PKPViewableFilePlugin extends GenericPlugin {
 	}
 }
 
-?>
+
