@@ -3,9 +3,9 @@
 /**
  * @file classes/search/SearchHTMLParser.inc.php
  *
- * Copyright (c) 2014-2016 Simon Fraser University Library
- * Copyright (c) 2000-2016 John Willinsky
- * Distributed under the GNU GPL v2. For full terms see the file docs/COPYING.
+ * Copyright (c) 2014-2021 Simon Fraser University
+ * Copyright (c) 2000-2021 John Willinsky
+ * Distributed under the GNU GPL v3. For full terms see the file docs/COPYING.
  *
  * @class SearchHTMLParser
  * @ingroup search
@@ -21,7 +21,7 @@ class SearchHTMLParser extends SearchFileParser {
 
 	function doRead() {
 		// strip HTML tags from the read line
-		$line = fgetss($this->fp, 4096);
+		$line = strip_tags(fgets($this->fp));
 
 		// convert HTML entities to valid UTF-8 characters
 		$line = html_entity_decode($line, ENT_COMPAT, 'UTF-8');
@@ -33,4 +33,4 @@ class SearchHTMLParser extends SearchFileParser {
 	}
 }
 
-?>
+
