@@ -3,9 +3,9 @@
 /**
  * @file controllers/grid/files/productionReady/ProductionReadyFilesGridHandler.inc.php
  *
- * Copyright (c) 2014-2016 Simon Fraser University Library
- * Copyright (c) 2003-2016 John Willinsky
- * Distributed under the GNU GPL v2. For full terms see the file docs/COPYING.
+ * Copyright (c) 2014-2021 Simon Fraser University
+ * Copyright (c) 2003-2021 John Willinsky
+ * Distributed under the GNU GPL v3. For full terms see the file docs/COPYING.
  *
  * @class ProductionReadyFilesGridHandler
  * @ingroup controllers_grid_files_productionready
@@ -19,12 +19,12 @@ class ProductionReadyFilesGridHandler extends FileListGridHandler {
 	/**
 	 * Constructor
 	 */
-	function ProductionReadyFilesGridHandler() {
+	function __construct() {
 		import('lib.pkp.controllers.grid.files.SubmissionFilesGridDataProvider');
-		parent::FileListGridHandler(
+		parent::__construct(
 			new SubmissionFilesGridDataProvider(SUBMISSION_FILE_PRODUCTION_READY),
 			WORKFLOW_STAGE_ID_PRODUCTION,
-			FILE_GRID_ADD|FILE_GRID_DELETE|FILE_GRID_VIEW_NOTES|FILE_GRID_EDIT
+			FILE_GRID_ADD|FILE_GRID_DELETE|FILE_GRID_VIEW_NOTES|FILE_GRID_EDIT|FILE_GRID_DOWNLOAD_ALL
 		);
 
 		$this->addRoleAssignment(
@@ -40,15 +40,9 @@ class ProductionReadyFilesGridHandler extends FileListGridHandler {
 				'deleteFile',
 			)
 		);
-	}
 
-	/**
-	 * @copydoc PKPHandler::initialize()
-	 */
-	function initialize($request) {
-		parent::initialize($request);
 		$this->setTitle('editor.submission.production.productionReadyFiles');
 	}
 }
 
-?>
+
